from logging.config import fileConfig
from pathlib import Path

from alembic import context
from sqlmodel import create_engine


# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = None

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    sqlite_path = context.get_x_argument(as_dictionary=True).get("sqlite_path")

    if sqlite_path is None:
        raise ValueError("sqlite_path argument is required")

    sqlite_path = Path(sqlite_path).absolute()

    context.configure(
        url=f"sqlite:///{sqlite_path}",
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """

    # sqlite_path = context.get_x_argument(as_dictionary=True).get("sqlite_path")

    # if sqlite_path is None:
    #     raise ValueError("sqlite_path argument is required")

    # connectable = create_sqlite_engine(sqlite_path)
    print(config.get_main_option("sqlalchemy.url"))
    connectable = create_engine(config.get_main_option("sqlalchemy.url"))

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
